/*
 * eos - A 3D Morphable Model fitting library written in modern C++11/14.
 *
 * File: include/eos/render/detail/Vertex.hpp
 *
 * Copyright 2017, 2023 Patrik Huber
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#pragma once

#ifndef EOS_VERTEX_HPP
#define EOS_VERTEX_HPP

#include "Eigen/Core"

/**
 * The detail namespace contains implementations of internal functions, not part of the API we expose and not
 * meant to be used by a user.
 */
namespace eos {
namespace render {
namespace detail {

/**
 * @brief A representation for a vertex during rendering, used internally.
 *
 * It's used to build the vertices that will be rendered, and new vertices that are generated by the renderer
 * (during clipping).
 * I should check at some point that no unnecessary copies of the vertex data is created in some places, but I
 * think it's pretty much fine.
 *
 * FragmentShader and SoftwareRenderer use this.
 *
 * This is the same as the one in the current render_detail.hpp, except that this is fully templated.
 *
 */
template <typename T>
struct Vertex
{
    Eigen::Vector4<T> position;  // XYZW
    Eigen::Vector3<T> color;     // RGB order
    Eigen::Vector2<T> texcoords; // UV
};

} /* namespace detail */
} /* namespace render */
} /* namespace eos */

#endif /* EOS_VERTEX_HPP */
